package com.displaynone.acss.ui.admin

import android.os.Bundle
import android.view.View
import androidx.fragment.app.Fragment
import androidx.fragment.app.viewModels
import com.displaynone.acss.R
import com.displaynone.acss.util.collectWithLifecycle
import com.displaynone.acss.util.navigateTo
import com.displaynone.acss.databinding.FragmentAdminBinding
import com.displaynone.acss.databinding.FragmentAuthBinding

class AdminFragment : Fragment(R.layout.fragment_admin) {
    private var _binding: FragmentAdminBinding? = null
    private val binding: FragmentAdminBinding get() = _binding!!

    private val viewModel: AdminViewModel by viewModels()

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)
        _binding = FragmentAdminBinding.bind(view)

        subscribeToState(view)

        binding.buttonSearch.setOnClickListener{
            onSearchButtonClicked()
        }
    }

    private fun onSearchButtonClicked() {
        val login = binding.loginSearch.text.toString()
        if (login.isEmpty()) return

        viewModel.getDataByLogin(login)
    }

    private fun subscribeToState(view: View){
        viewModel.state.collectWithLifecycle(this){ state ->
            if (state is AdminViewModel.State.Show){
                val userDto = state.item
                val bundle = Bundle().apply{
                    putSerializable("user", userDto)
                }
                navigateTo(view, R.id.action_adminFragment_to_profileFragment, bundle)
            }
        }
    }
}